

..

    Add mentions to graphics early in tutorial, how to inspect

    Add complement somewhere


    Fetching external gene tracks
    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

    [if pyranges_db is a thing, describe its uses here]




    RLEs: run length encodings
    ~~~~~~~~~~~~~~~~~~~~~~~~~~

    [outline as advanced usage. Put everything related to RLEs in a single chapter; keep as last even if you add further chapters]


